@@ -7,7 +7,6 @@ from bs4.element import ResultSet  # type: ignore
 
 from dateutil import parser
 
-from circuit_maintenance_parser.errors import ParsingError
 from circuit_maintenance_parser.parser import Html, Impact, CircuitImpact, Status
 
 # pylint: disable=too-many-nested-blocks,no-member, too-many-branches
@@ -19,17 +18,13 @@ logger = logging.getLogger(__name__)
 class HtmlParserZayo1(Html):
     """Notifications Parser for Zayo notifications."""
 
-    def parse_html(self, soup, data_base):
+    def parse_html(self, soup):
         """Execute parsing."""
-        data = data_base.copy()
-        try:
-            self.parse_bs(soup.find_all("b"), data)
-            self.parse_tables(soup.find_all("table"), data)
+        data = {}
+        self.parse_bs(soup.find_all("b"), data)
+        self.parse_tables(soup.find_all("table"), data)
 
-            return [data]
-
-        except Exception as exc:
-            raise ParsingError from exc
+        return [data]
 
     def parse_bs(self, btags: ResultSet, data: dict):
         """Parse B tag."""
@@ -66,13 +61,16 @@ class HtmlParserZayo1(Html):
         circuits = []
         for table in tables:
             head_row = table.find_all("th")
-            if len(head_row) < 5 or [self.clean_line(line) for line in head_row[:5]] != [
-                "Circuit Id",
-                "Expected Impact",
-                "A Location CLLI",
-                "Z Location CLLI",
-                "Legacy Circuit Id",
-            ]:
+            if len(head_row) < 5:
+                logger.warning("Less table headers than expected: %s", head_row)
+                continue
+
+            table_headers = [self.clean_line(line) for line in head_row[:5]]
+            expected_headers_ref = (
+                ["Circuit Id", "Expected Impact", "A Location CLLI", "Z Location CLLI", "Legacy Circuit Id",],
+                ["Circuit Id", "Expected Impact", "A Location Address", "Z Location Address", "Legacy Circuit Id",],
+            )
+            if all(table_headers != expected_headers for expected_headers in expected_headers_ref):
                 logger.warning("Table headers are not as expected: %s", head_row)
                 continue
 
@@ -87,4 +85,5 @@ class HtmlParserZayo1(Html):
                 if "hard down" in impact.lower():
                     data_circuit["impact"] = Impact("OUTAGE")
                     circuits.append(CircuitImpact(**data_circuit))
-        data["circuits"] = circuits
+        if circuits:
+            data["circuits"] = circuits
